@@ -3,7 +3,7 @@ import sys
 
 sys.path.append('../')
 from ctypes import *
-from SNR_ESTIMATION.structFormat import emxArray_real_T,get_data_of_ctypes_
+from commFunction import emxArray_real_T,get_data_of_ctypes_
 import ctypes
 
 
@@ -15,8 +15,8 @@ def cal_snr_transient(refFile=None, noisetFile=None, testFile=None):
     """
     """
     refstruct,refsamplerate,_ = get_data_of_ctypes_(refFile)
-    teststruct,testsamplerate,_ = get_data_of_ctypes_(noisetFile)
-    noiseStruct,noisesamplerate,_ = get_data_of_ctypes_(testFile)
+    teststruct,testsamplerate,_ = get_data_of_ctypes_(testFile)
+    noiseStruct,noisesamplerate,_ = get_data_of_ctypes_(noisetFile)
     if refsamplerate != testsamplerate or refsamplerate!= noisesamplerate:
         raise TypeError('Different format of ref and test files!')
     mydll = ctypes.windll.LoadLibrary(sys.prefix + '/snr_transient.dll')
