@@ -22,8 +22,11 @@ from ctypes import  *
 from SNR_ESTIMATION.MATCH_SIG import match_sig
 from SNR_ESTIMATION.SNR_MUSIC import cal_snr_music
 from SNR_ESTIMATION.SNR_TRANSIENT import cal_snr_transient
+from AGC_EVALUATION.CAL_GAIN_TABLE import cal_gain_table
+from AGC_EVALUATION.CAL_ATTACK_RELEASE import cal_attack_release
+from AGC_EVALUATION.CAL_MUSIC_STABILITY import cal_music_stablility
 
-allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR','SII','LOUDNESS','MUSIC','TRANSIENT','MATCH']
+allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR','SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE','ATTACKRELEASE','MUSICSTA']
 
 
 class computeAudioQuality():
@@ -54,6 +57,7 @@ class computeAudioQuality():
         self.testOffset = kwargs['refOffset']
         self.maxComNLevel = kwargs['maxComNLevel']
         self.speechPauseLevel = kwargs['speechPauseLevel']
+        self.gaintableType = kwargs["gaintableType"]
         #maxComNLevel=c_double(-48.0),speechPauseLevel=c_double(-35.0)
 
     def __chcek_valid(self):
@@ -184,7 +188,6 @@ class computeAudioQuality():
         self.__double_end_check()
         ref, ins = self.__data_convert(wav2pcm(resample(pcm2wav(self.refFile),16000)),wav2pcm(resample(pcm2wav(self.testFile),16000)))
         result = cal_stoi(ref,ins,sr=16000)
-        print(result)
         return result
         pass
 
@@ -220,8 +223,7 @@ class computeAudioQuality():
         """
         self.__double_end_check()
         ref, ins = self.__data_convert(wav2pcm(resample(pcm2wav(self.refFile),16000)),wav2pcm(resample(pcm2wav(self.testFile),16000)))
-        result = cal_stoi(ref,ins,sr=16000)
-        print(result)
+        result = cal_sdr(ref,ins,sr=16000)
         return result
         pass
 
@@ -233,7 +235,6 @@ class computeAudioQuality():
         :return:
         """
         self.__double_end_check()
-        print(self.refFile,self.testFile)
         return cal_snr_music(refFile=pcm2wav(self.refFile,sample_rate=self.samplerate),testFile=pcm2wav(self.testFile,sample_rate=self.samplerate))
 
     def TRANSIENT(self):
@@ -267,3 +268,32 @@ class computeAudioQuality():
     def __cal_sii__(self):
         #return cal_sii()
         pass
+
+    def GAINTABLE(self):
+        """
+        AGC PARA 1
+        计算agc的gain table
+        :return:
+        """
+        self.__double_end_check()
+        return cal_gain_table(refFile=pcm2wav(self.refFile, sample_rate=self.samplerate),
+                             testFile=pcm2wav(self.testFile, sample_rate=self.samplerate),targetType=self.gaintableType)
+
+    def ATTACKRELEASE(self):
+        """
+        AGC PARA 2
+        计算agc的attack release
+        :return:
+        """
+        self.__double_end_check()
+        return cal_attack_release(refFile=pcm2wav(self.refFile, sample_rate=self.samplerate),
+                             testFile=pcm2wav(self.testFile, sample_rate=self.samplerate))
+    def MUSICSTA(self):
+        """
+        AGC PARA 3
+        计算music 信号稳定性
+        :return:
+        """
+        self.__double_end_check()
+        return cal_music_stablility(refFile=pcm2wav(self.refFile, sample_rate=self.samplerate),
+                             testFile=pcm2wav(self.testFile, sample_rate=self.samplerate))
\ No newline at end of file
